@@ -8,24 +8,30 @@ import org.gnu.glade.LibGlade;
 import org.gnu.gtk.Entry;
 import org.gnu.gtk.Gtk;
 
-public class Simple {
-	
-	private LibGlade glade;
-	Entry e;
-	
+public class Simple
+{
+
+	private LibGlade	glade;
+
+	Entry				e;
+
 	public Simple() throws GladeXMLException, FileNotFoundException, IOException {
 		glade = new LibGlade("overholt/simple.glade", this);
-		e = (Entry)glade.getWidget("entry1");
+		e = (Entry) glade.getWidget("entry1");
 	}
-	
+
 	public void on_button1_clicked() {
 		System.out.println(e.getText());
 	}
 
+	public void gtkMainQuit() {
+		Gtk.mainQuit();
+	}
+
 	public static void main(String[] args) {
 
 		Simple simple;
-		
+
 		try {
 			Gtk.init(args);
 			simple = new Simple();
@@ -33,6 +39,6 @@ public class Simple {
 		} catch (Exception e) {
 			e.printStackTrace();
 		}
-		
+
 	}
 }
